==> malt-0.0.3.tgz: package/lib/core/models/remote.js <==
var Structr = require('structr'),
AbstractModel = require('./abstract');


module.exports = AbstractModel.extend({
	

	/**
	 * syncs the model from the server
	 */

	'sync': function(listeners)
	{
		if(this.loaded)
		{
			if(listeners.loaded) listeners.loaded();

			return;	
		}

		this.subscribe(listeners);

		this.load();

		return this;
	},

	/**
	 */

	'unsync': function()
	{
		if(this._listener)
		{
			this._listener.dispose();
			this._listener = null;
		}	

		return this;
	},


	/**
	 */

	'load': function(method, data, callback)
	{
		if(typeof method == 'object')
		{
			callback = data;
			data = method;
			method = undefined;
		}

		if(typeof method == 'function')
		{
			callback = method;
			method = undefined;
			data = undefined;
		}


		if(callback) this.subscribeOnce('loaded', callback);


		if(this._loading) return;
		this._loading = true;

		var self = this;
		
		this._load(method, data, function(response)
		{
			self.loaded = true;

			self._onResponse(response);
			self._loading = false;
			self.change('loaded', self);
		});
			
		return this;
	},

	/**
	 */

	'_load': function(method, data, callback)
	{ 
		this._pull(method, data, callback);	
	},


	/**
	 */

	'toJSON': function()
	{
		return this.doc;
	},

	/**
	 */

	'_channel': function()
	{
		return this.channel;
	},

	/**
	 */

	'_onResponse': function(response)
	{
		//abstract
	},

	/**

	 */

	'_pull': function(method, data, onResponse)
	{
		if(typeof data == 'function')
		{
			onResponse = data;
			data = null;
		}

		
		this.router.pull(this._channel(), data, { meta: { method: method }}, onResponse || function(){});
	},


	/**
	 */

	'_initPush': function()
	{
		if(this._listener) return this;



		this._listener = this.router.on(this._channel(), { type: 'push', meta: { 'public': 1 } }, this.getMethod('_onResponse'));	
		return this;
	}

});

==> malt-0.0.5.tgz: package/lib/core/models/remote.js <==
var Structr = require('structr'),
AbstractModel = require('./abstract');


module.exports = AbstractModel.extend({
	

	/**
	 * syncs the model from the server
	 */

	'sync': function(listeners)
	{
		if(this.loaded)
		{
			if(listeners.loaded) listeners.loaded();

			return;	
		}

		this.subscribe(listeners);

		this.load();

		return this;
	},

	/**
	 */

	'unsync': function()
	{
		if(this._listener)
		{
			this._listener.dispose();
			this._listener = null;
		}	

		return this;
	},


	/**
	 */

	'load': function(method, data, callback)
	{
		if(typeof method == 'object')
		{
			callback = data;
			data = method;
			method = undefined;
		}

		if(typeof method == 'function')
		{
			callback = method;
			method = undefined;
			data = undefined;
		}
                                                                

		if(this._loading) return;
		this._loading = true;

		var self = this;
		
		var callSuccess = this._load(method, data, function(response)
		{
			self.loaded = true;

			self._onResponse(response);


			if(self.router)
			{
				if(response.errors)
				{
					self.router.push('alert/error', response.errors);
				}

				if(response.warnings)
				{
					self.router.push('alert/warning', response.warnings);
				} 
			}                      
			
			if(callback) callback(response.errors, response.result);

			self._loading = false;
			self.change('loaded', self);
		});   
		
		if(!callSuccess && callback)
		{
			callback(new Error('route does not exist'));
		}
			
		return this;
	},

	/**
	 */

	'_load': function(method, data, callback)
	{ 
		return this._pull(method, data, callback);	
	},


	/**
	 */

	'toJSON': function()
	{
		return this.doc;
	},

	/**
	 */

	'_channel': function()
	{
		return this.channel;
	},

	/**
	 */

	'_onResponse': function(response)
	{
		//abstract
	},

	/**

	 */

	'_pull': function(method, data, onResponse)
	{
		if(typeof data == 'function')
		{
			onResponse = data;
			data = null;
		}
            
		return this.router.pull(this._channel(), data, { meta: { method: method }}, onResponse || function(){});
	},


	/**
	 */

	'_initPush': function()
	{
		if(this._listener) return this;



		this._listener = this.router.on(this._channel(), { type: 'push', meta: { 'public': 1 } }, this.getMethod('_onResponse'));	
		return this;
	}

});
